Index: configure.ac
===================================================================
--- configure.ac	(revision 374930)
+++ configure.ac	(working copy)
@@ -254,6 +254,7 @@
 AC_PATH_PROG([DIRNAME], [dirname], :)
 AC_PATH_PROG([SHELL], [sh], :)
 AC_PATH_PROG([LN], [ln], :)
+AC_PATH_PROG([DOXYGEN], [doxygen], :)
 AC_PATH_PROG([DOT], [dot], :)
 AC_PATH_PROG([WGET], [wget], :)
 AC_PATH_PROG([CURL], [curl], :)
Index: Makefile
===================================================================
--- Makefile	(revision 374930)
+++ Makefile	(working copy)
@@ -292,13 +292,6 @@
 SUBMAKE:=$(MAKE) --quiet --no-print-directory
 endif
 
-# This is used when generating the doxygen documentation
-ifneq ($(DOT),:)
-  HAVEDOT=yes
-else
-  HAVEDOT=no
-endif
-
 # $(MAKE) is printed in several places, and we want it to be a
 # fixed size string. Define a variable whose name has also the
 # same size, so we can easily align text.
@@ -743,10 +736,25 @@
 	@echo " +-------------------------------------------+"
 
 progdocs:
-	doxygen -u contrib/asterisk-ng-doxygen
-	(cat contrib/asterisk-ng-doxygen; echo "HAVE_DOT=$(HAVEDOT)"; \
-	echo "PROJECT_NUMBER=$(ASTERISKVERSION)") | doxygen -
-	rm -f contrib/asterisk-ng-doxygen.bak
+	# Note, the Makefile operations must not be tabbed out. Wasted hours with that.
+ifeq ($(DOXYGEN),:)
+	@echo "Doxygen is not installed.  Please install and re-run the configuration script."
+else
+ifeq ($(DOT),:)
+	@echo "DOT is not installed. Doxygen will not produce any diagrams."
+else
+	# Enable DOT
+	@sed -i "/^HAVE_DOT/s/NO/YES/" contrib/asterisk-ng-doxygen
+endif
+	# Set Doxygen PROJECT_NUMBER variable
+	@sed -i "/^PROJECT_NUMBER/s/PROJECT_NUMBER.*/PROJECT_NUMBER = "$(ASTERISKVERSION)"/" contrib/asterisk-ng-doxygen
+	# Validate Doxygen Configuration
+	@doxygen -u contrib/asterisk-ng-doxygen
+	# Run Doxygen
+	@doxygen contrib/asterisk-ng-doxygen
+	# Remove configuration backup file
+	@rm -f contrib/asterisk-ng-doxygen.bak
+endif
 
 install-logrotate:
 	if [ ! -d "$(DESTDIR)$(ASTETCDIR)/../logrotate.d" ]; then \
Index: makeopts.in
===================================================================
--- makeopts.in	(revision 374930)
+++ makeopts.in	(working copy)
@@ -21,6 +21,7 @@
 BASENAME=@BASENAME@
 SHELL=@SHELL@
 LN=@LN@
+DOXYGEN=@DOXYGEN@
 DOT=@DOT@
 STRIP=@STRIP@
 WGET=@WGET@
